package com.ruoyi.bst.gateway.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.gateway.domain.Gateway;
import com.ruoyi.bst.gateway.domain.GatewayQuery;
import com.ruoyi.bst.gateway.domain.GatewayVO;
import com.ruoyi.bst.gateway.mapper.GatewayMapper;
import com.ruoyi.bst.gateway.service.GatewayService;
import com.ruoyi.common.utils.DateUtils;

/**
 * 网关Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-17
 */
@Service
public class GatewayServiceImpl implements GatewayService
{
    @Autowired
    private GatewayMapper gatewayMapper;

    /**
     * 查询网关
     *
     * @param id 网关主键
     * @return 网关
     */
    @Override
    public GatewayVO selectGatewayById(Long id)
    {
        return gatewayMapper.selectGatewayById(id);
    }

    /**
     * 查询网关列表
     *
     * @param gateway 网关
     * @return 网关
     */
    @Override
    public List<GatewayVO> selectGatewayList(GatewayQuery gateway)
    {
        return gatewayMapper.selectGatewayList(gateway);
    }

    /**
     * 新增网关
     *
     * @param gateway 网关
     * @return 结果
     */
    @Override
    public int insertGateway(Gateway gateway)
    {
        gateway.setCreateTime(DateUtils.getNowDate());
        return gatewayMapper.insertGateway(gateway);
    }

    /**
     * 修改网关
     *
     * @param gateway 网关
     * @return 结果
     */
    @Override
    public int updateGateway(Gateway gateway)
    {
        return gatewayMapper.updateGateway(gateway);
    }

    /**
     * 批量删除网关
     *
     * @param ids 需要删除的网关主键
     * @return 结果
     */
    @Override
    public int deleteGatewayByIds(Long[] ids)
    {
        return gatewayMapper.deleteGatewayByIds(ids);
    }

    /**
     * 删除网关信息
     *
     * @param id 网关主键
     * @return 结果
     */
    @Override
    public int deleteGatewayById(Long id)
    {
        return gatewayMapper.deleteGatewayById(id);
    }
}
