package com.ruoyi.bst.gatewayDevice.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.gatewayDevice.domain.GatewayDevice;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceQuery;
import com.ruoyi.bst.gatewayDevice.domain.GatewayDeviceVO;
import com.ruoyi.bst.gatewayDevice.mapper.GatewayDeviceMapper;
import com.ruoyi.bst.gatewayDevice.service.GatewayDeviceService;
import com.ruoyi.common.utils.DateUtils;

/**
 * 网关设备Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-17
 */
@Service
public class GatewayDeviceServiceImpl implements GatewayDeviceService
{
    @Autowired
    private GatewayDeviceMapper gatewayDeviceMapper;

    /**
     * 查询网关设备
     *
     * @param id 网关设备主键
     * @return 网关设备
     */
    @Override
    public GatewayDeviceVO selectGatewayDeviceById(Long id)
    {
        return gatewayDeviceMapper.selectGatewayDeviceById(id);
    }

    /**
     * 查询网关设备列表
     *
     * @param gatewayDevice 网关设备
     * @return 网关设备
     */
    @Override
    public List<GatewayDeviceVO> selectGatewayDeviceList(GatewayDeviceQuery gatewayDevice)
    {
        return gatewayDeviceMapper.selectGatewayDeviceList(gatewayDevice);
    }

    /**
     * 新增网关设备
     *
     * @param gatewayDevice 网关设备
     * @return 结果
     */
    @Override
    public int insertGatewayDevice(GatewayDevice gatewayDevice)
    {
        gatewayDevice.setCreateTime(DateUtils.getNowDate());
        return gatewayDeviceMapper.insertGatewayDevice(gatewayDevice);
    }

    /**
     * 修改网关设备
     *
     * @param gatewayDevice 网关设备
     * @return 结果
     */
    @Override
    public int updateGatewayDevice(GatewayDevice gatewayDevice)
    {
        return gatewayDeviceMapper.updateGatewayDevice(gatewayDevice);
    }

    /**
     * 批量删除网关设备
     *
     * @param ids 需要删除的网关设备主键
     * @return 结果
     */
    @Override
    public int deleteGatewayDeviceByIds(Long[] ids)
    {
        return gatewayDeviceMapper.deleteGatewayDeviceByIds(ids);
    }

    /**
     * 删除网关设备信息
     *
     * @param id 网关设备主键
     * @return 结果
     */
    @Override
    public int deleteGatewayDeviceById(Long id)
    {
        return gatewayDeviceMapper.deleteGatewayDeviceById(id);
    }
}
