package com.ruoyi.web.bst;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.gateway.domain.Gateway;
import com.ruoyi.bst.gateway.domain.GatewayQuery;
import com.ruoyi.bst.gateway.domain.GatewayVO;
import com.ruoyi.bst.gateway.service.GatewayIotService;
import com.ruoyi.bst.gateway.service.GatewayService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.iot.constants.IotConstants;

/**
 * 网关Controller
 *
 * @author ruoyi
 * @date 2025-04-17
 */
@RestController
@RequestMapping("/bst/gateway")
public class GatewayController extends BaseController
{
    @Autowired
    private GatewayService gatewayService;

    @Autowired
    private GatewayIotService gatewayIotService;

    /**
     * 查询网关列表
     */
    @PreAuthorize("@ss.hasPermi('bst:gateway:list')")
    @GetMapping("/list")
    public TableDataInfo list(GatewayQuery query)
    {
        startPage();
        startOrderBy();
        List<GatewayVO> list = gatewayService.selectGatewayList(query);
        if (query.getRefresh() != null && query.getRefresh()) {
            gatewayIotService.refresh(list, IotConstants.ONLINE_TYPE_COMMAND);
        }
        return getDataTable(list);
    }

    /**
     * 导出网关列表
     */
    @PreAuthorize("@ss.hasPermi('bst:gateway:export')")
    @Log(title = "网关", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GatewayQuery query)
    {
        List<GatewayVO> list = gatewayService.selectGatewayList(query);
        ExcelUtil<GatewayVO> util = new ExcelUtil<GatewayVO>(GatewayVO.class);
        util.exportExcel(response, list, "网关数据");
    }

    /**
     * 获取网关详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:gateway:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id, @RequestParam( required = false, defaultValue = "false") Boolean refresh)
    {
        GatewayVO gateway = gatewayService.selectGatewayById(id);
        if (refresh != null && refresh) {
            gatewayIotService.refresh(gateway, IotConstants.ONLINE_TYPE_COMMAND);
        }
        return success(gateway);
    }

    /**
     * 新增网关
     */
    @PreAuthorize("@ss.hasPermi('bst:gateway:add')")
    @Log(title = "网关", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Gateway gateway)
    {
        return toAjax(gatewayService.insertGateway(gateway));
    }

    /**
     * 修改网关
     */
    @PreAuthorize("@ss.hasPermi('bst:gateway:edit')")
    @Log(title = "网关", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Gateway gateway)
    {
        return toAjax(gatewayService.updateGateway(gateway));
    }

    /**
     * 删除网关
     */
    @PreAuthorize("@ss.hasPermi('bst:gateway:remove')")
    @Log(title = "网关", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gatewayService.deleteGatewayByIds(ids));
    }
}
